using System.Threading.Tasks;
using FluentAssertions;
using Microsoft.AspNetCore.Mvc;
using Microsoft.Extensions.Logging;
using NSubstitute;
using NSubstitute.ExceptionExtensions;
using Robware.Api.Blog.Controllers;
using Robware.Blog;
using Robware.Data;
using Xunit;

namespace Robware.Api.Blog.Tests {
	public class BlogControllerTests {
		[Fact]
		public async Task Get_WithUrl_ReturnsBlogPost() {
			var logger = Substitute.For<ILogger<BlogController>>();
			var repo = Substitute.For<IBlogRepository>();

			repo.GetPostByUrlAsync("url").Returns(new BlogPost());

			var expectation = new BlogPost();

			var controller = new BlogController(logger, repo);
			(await controller.Get("url")).Value.Should().BeEquivalentTo(expectation);
		}

		[Fact]
		public async Task Get_WithId_ReturnsBlogPost() {
			var logger = Substitute.For<ILogger<BlogController>>();
			var repo = Substitute.For<IBlogRepository>();

			repo.GetPostByIdAsync(1).Returns(new BlogPost());

			var expectation = new BlogPost();

			var controller = new BlogController(logger, repo);
			(await controller.Get("1")).Value.Should().BeEquivalentTo(expectation);
		}

		[Fact]
		public async Task Get_WithInvalidUrl_Returns404() {
			var logger = Substitute.For<ILogger<BlogController>>();
			var repo = Substitute.For<IBlogRepository>();

			repo.GetPostByUrlAsync("url").Throws(new ItemNotFoundException("", null));

			var controller = new BlogController(logger, repo);
			(await controller.Get("url")).Result.Should().BeOfType<NotFoundObjectResult>();

		}
	}
}
