﻿using System.Collections.Generic;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Mvc;
using Microsoft.Extensions.Logging;
using Robware.Blog;
using Robware.Data;

namespace Robware.Api.Blog.Controllers {
	[ApiController]
	public class BlogController : ControllerBase {
		private readonly ILogger<BlogController> _logger;
		private readonly IBlogRepository _blogRepository;

		public BlogController(ILogger<BlogController> logger, IBlogRepository blogRepository) {
			_logger = logger;
			_blogRepository = blogRepository;
		}

		[HttpGet(nameof(Get) + "/{url}")]
		public async Task<ActionResult<BlogPost>> Get(string url) {
			_logger.Log(LogLevel.Information, $"{nameof(Get)}: {nameof(url)}={url}");

			try {
				if (int.TryParse(url, out int id)) {
					return await _blogRepository.GetPostByIdAsync(id);
				}

				return await _blogRepository.GetPostByUrlAsync(url);
			}
			catch (ItemNotFoundException e) {
				_logger.Log(LogLevel.Error, e.Message);
				return NotFound("Could not find blog post");
			}
		}

		//[HttpGet]
		//Task<BlogPost> GetPostByUrl();

		//[HttpGet]
		//Task<IEnumerable<BlogPost>> GetLatestPosts(int limit, int offset = 0);

		//[HttpGet]
		//Task<BlogPost> GetLatestPost();

		//[HttpGet]
		//Task<int> GetCount();

		//[HttpGet]
		//Task<BlogPost> GetPostById(int id);

		//[HttpPost]
		//Task<BlogPost> SavePost(BlogPost post);

		//[HttpGet]
		//Task<IEnumerable<BlogPost>> GetAllPosts();

		//[HttpGet]
		//Task DeletePost(int id);
	}
}
